@@ -1,6 +1,11 @@
-#!/usr/bin/perl
-
+use strict;
+use warnings;
 package Search::GIN::Core;
+BEGIN {
+  $Search::GIN::Core::VERSION = '0.05';
+}
+# ABSTRACT: Core of Search::GIN
+
 use Moose::Role;
 
 use Data::Stream::Bulk::Util qw(bulk unique);
@@ -63,6 +68,32 @@ sub insert {
     }
 }
 
-__PACKAGE__
+1;
+
+
+
+=pod
+
+=head1 NAME
+
+Search::GIN::Core - Core of Search::GIN
+
+=head1 VERSION
+
+version 0.05
+
+=head1 AUTHOR
+
+  Yuval Kogman <nothingmuch@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
 
 __END__
