@@ -1,8 +1,12 @@
-#!/usr/bin/perl
-
+use strict;
+use warnings;
 package Search::GIN::Extract::Attributes;
-use Moose;
+BEGIN {
+  $Search::GIN::Extract::Attributes::VERSION = '0.05';
+}
+# ABSTRACT:
 
+use Moose;
 use namespace::clean -except => 'meta';
 
 with qw(
@@ -21,7 +25,10 @@ sub extract_values {
 
     my @meta_attrs = $self->get_meta_attrs($obj, @args);
 
-    return $self->process_keys({ map { $_->name => $_->get_value($obj) } @meta_attrs });
+    return $self->process_keys({ map {
+                                    my $val = $_->get_value($obj);
+                                    $_->name => (defined($val) ? $val : undef);
+                                } @meta_attrs });
 }
 
 sub get_meta_attrs {
@@ -33,19 +40,23 @@ sub get_meta_attrs {
     if ( $self->has_attributes ) {
         return grep { defined } map { $meta->find_attribute_by_name($_) } @{ $self->attributes };
     } else {
-        return $meta->compute_all_applicable_attributes;
+        return $meta->get_all_attributes;
     }
 }
 
-__PACKAGE__
+1;
+
 
-__END__
 
 =pod
 
 =head1 NAME
 
-Search::GIN::Extract::Attributes - 
+Search::GIN::Extract::Attributes - use Moose;
+
+=head1 VERSION
+
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -53,6 +64,19 @@ Search::GIN::Extract::Attributes -
 
 =head1 DESCRIPTION
 
+=head1 AUTHOR
+
+  Yuval Kogman <nothingmuch@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 
+__END__
+
