@@ -1,10 +1,13 @@
-#!/usr/bin/perl
-
+use strict;
+use warnings;
 package Search::GIN::Extract::Class;
+BEGIN {
+  $Search::GIN::Extract::Class::VERSION = '0.05';
+}
+# ABSTRACT:
+
 use Moose;
-
 use MRO::Compat;
-
 use namespace::clean -except => 'meta';
 
 with qw(
@@ -29,15 +32,19 @@ sub extract_values {
     });
 }
 
-__PACKAGE__
+1;
+
 
-__END__
 
 =pod
 
 =head1 NAME
 
-Search::GIN::Extract::Class - 
+Search::GIN::Extract::Class - use Moose;
+
+=head1 VERSION
+
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -45,6 +52,19 @@ Search::GIN::Extract::Class -
 
 =head1 DESCRIPTION
 
+=head1 AUTHOR
+
+  Yuval Kogman <nothingmuch@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
 
+__END__
+
