@@ -1,10 +1,13 @@
-#!/usr/bin/perl
-
+use strict;
+use warnings;
 package Search::GIN::Query::Attributes;
+BEGIN {
+  $Search::GIN::Query::Attributes::VERSION = '0.05';
+}
+# ABSTRACT: Create attributes-based GIN queries
+
 use Moose;
-
 use Carp qw(croak);
-
 use namespace::clean -except => [qw(meta)];
 
 with qw(
@@ -79,9 +82,9 @@ sub compare_test_deep {
 
 __PACKAGE__->meta->make_immutable;
 
-__PACKAGE__
+1;
+
 
-__END__
 
 =pod
 
@@ -89,6 +92,10 @@ __END__
 
 Search::GIN::Query::Attributes - Create attributes-based GIN queries
 
+=head1 VERSION
+
+version 0.05
+
 =head1 SYNOPSIS
 
     use Search::GIN::Query::Attributes;
@@ -126,4 +133,19 @@ Attributes of the object you want to find.
         },
     );
 
+=head1 AUTHOR
+
+  Yuval Kogman <nothingmuch@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
