@@ -1,10 +1,13 @@
-#!/usr/bin/perl
-
+use strict;
+use warnings;
 package Search::GIN::Query::Class;
+BEGIN {
+  $Search::GIN::Query::Class::VERSION = '0.05';
+}
+# ABSTRACT: Create class-based GIN queries
+
 use Moose;
-
 use Carp qw(croak);
-
 use namespace::clean -except => [qw(meta)];
 
 with qw(
@@ -90,9 +93,9 @@ sub check_object {
 
 __PACKAGE__->meta->make_immutable;
 
-__PACKAGE__
+1;
+
 
-__END__
 
 =pod
 
@@ -100,6 +103,10 @@ __END__
 
 Search::GIN::Query::Class - Create class-based GIN queries
 
+=head1 VERSION
+
+version 0.05
+
 =head1 SYNOPSIS
 
     use Search::GIN::Query::Class;
@@ -147,4 +154,19 @@ The name of the package that the object is blessed into.
         blessed => 'Person',
     );
 
+=head1 AUTHOR
+
+  Yuval Kogman <nothingmuch@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Yuval Kogman, Infinity Interactive.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
